# Furious

[![Github Deploy](https://github.com/LorenEteval/Furious/actions/workflows/deploy-pypi.yml/badge.svg?branch=main)](https://github.com/LorenEteval/Furious/actions/workflows/deploy-pypi.yml)

## Install

You can install from [release page](https://github.com/LorenEteval/Furious/releases) or
from [PyPI](https://pypi.org/project/Furious-GUI/).

## Wiki

* [TUN Mode](https://github.com/LorenEteval/Furious/wiki/TUN-Mode)
* [Install From PyPI](https://github.com/LorenEteval/Furious/wiki/Install-From-PyPI)

## Contribute

* Translations
* ...

## License

License under [GPL v3.0](https://github.com/LorenEteval/Furious/blob/main/LICENSE).

## Credits

* [Xray-core](https://github.com/XTLS/Xray-core)
* [hysteria](https://github.com/apernet/hysteria)
* [tun2socks](https://github.com/xjasonlyu/tun2socks)
* [v2rayN](https://github.com/2dust/v2rayN)
* [QDarkStyleSheet](https://github.com/ColinDuquesnoy/QDarkStyleSheet)
